# Flasik


---

## Directory Structure

```

    #ROOT
    |
    |-- __flasik__.py
    |
    |-- propel.yml
    |
    |-- requirements.txt
    |
    |-- /application
        |-- __init__.py
        |
        |-- commander.py
        |
        |-- config.py
        |
        |-- models.py    
        |
        |-- lib/
        |
        |-- static/ 
        |
        |-- var/
        |
        |-- views/
            |
            |-- main.py
            |
            |-- templates
                |
                |-- main/
                    |
                    |-- Index/
                        |
                        |-- index.html

```

## Serve your app

```
flasik-admin run
```

